package domein;

/**
 * Klasse Caesarcodering kan worden gebruikt om een 
 * bericht te coderen of te decoderen, gebruikmakend van 
 * de Caesarcodering die alle letters in een gegevens string 
 * een vast aantal posities door het alfabet verschuift.
 *
 */
public class CaesarCodering {
  private static final String alfabet = "abcdefghijklmnopqrstuvwxyz";
  

  /**
   * Codeert een bericht door alle letters het aantal posities
   * gegeven door sleutel door het alfabet te verschuiven. 
   * Het bericht wordt eerst geconverteerd naar 
   * onderkast. Tekens die geen letters zijn, worden weggelaten.
   * @param bericht het te coderen bericht
   * @param sleutel  het aantal te verschuiven posities
   * @return het gecodeerde bericht
   */
  public static String codeer(String bericht, int sleutel) {
    bericht = bericht.toLowerCase();
    String code = "";
    for (int c=0; c < bericht.length(); c++) {
      int indexOfC = alfabet.indexOf(bericht.charAt(c));
      if (indexOfC != -1) {
        int indexVerschoven = (indexOfC + sleutel) % 26;
        code = code + alfabet.charAt(indexVerschoven);
      }
    }
    return code;
  }
  
  /**
   * Deelt een (gecodeerd) bericht op in groepen van 
   * vijf letters, gescheiden door spaties
   * @param code  de te formatteren string
   * @return  de string met na elke vijfde letter
   *          een spatie
   */
  public static String formatteer(String code) {
    String geformatteerd = "";
    for (int c=0; c < code.length(); c++) {
      geformatteerd = geformatteerd + code.charAt(c);
      if ((c + 1) % 5 == 0) {
        geformatteerd = geformatteerd + " ";
      }
    }
    return geformatteerd;
  }  
}
